Learn R Programming

agridat (version 1.5)

cochran.eelworms: Counts of eelworms before and after fumigant treatments

Description

Counts of eelworms before and after fumigant treatments

Usage

data(cochran.eelworms)

Arguments

source

Cochran and Cox, 1950. Experimental Designs. Table 3.1.

Details

In the original experiment plan (as shown in Bailey 2008), columns 9, 10, 11 are shifted up slightly. Treatment codes: Con = Control, Chl = Chlorodinitrobenzen, Cym = Cymag, Car = Carbon Disulphide jelly, See = Seekay. Experiment was conducted in 1935 at Rothamsted Experiment Station. In early March 400 grams of soil were sampled and the number of eelworm cysts were counted. Fumigants were added to the soil, oats were sown and later harvested. In October, the plots were again sampled and the final count of cysts recorded.

References

R. A. Bailey, 2008. Design of Comparative Experiments. Cambridge.

Examples

Run this code
dat <- cochran.eelworms

# Some strong spatial trends
desplot(initial ~ col*row, data=dat, flip=TRUE)

# final counts are strongly related to initial counts
xyplot(final~initial|dose, data=dat, group=fumigant, auto.key=list(columns=5))

# One approach...log transform, use 'initial' as covariate, create 9 treatments
dat <- transform(dat, trt=factor(paste0(fumigant, dose)))
m1 <- aov(log(final) ~ block + trt + log(initial), data=dat)
anova(m1)

Run the code above in your browser using DataLab