A uniformity trial of sesame
delgadillolopez.sesame.uniformity.RdA uniformity trial of sesame in Nicaragua
Usage
data("delgadillolopez.sesame.uniformity")Format
A data frame with 384 observations on the following 3 variables.
rowrow ordinate
colcolumn ordinate
yieldyield, grams per plot
Details
A uniformity trial of sesame conducted in Managua, Nicaragua, in 1969.
Field width: 16 plots * 5 m = 80 m
Field length: 24 rows * 0.915 m = 21.96 m
Data provenance: Data appears in Delgadillo Lobez (1973) table 5. Typed by K.Wright. Table 6 shows 3-row subtotals that were used to correct some data values that were difficult to transcribe.