Learn R Programming

agridat (version 1.12)

gomez.stripplot: Rice strip-plot experiment

Description

A strip-plot experiment with three reps, variety as the horizontal strip and nitrogen fertilizer as the vertical strip.

Arguments

Format

yield

Grain yield in kg/ha

rep

Rep

nitro

Nitrogen fertilizer in kg/ha

gen

Rice variety

x

Ordinate in the field

y

Ordinate in the field

Details

Note, this is a subset of the the 'gomez.stripsplitplot' data.

References

Jan Gertheiss (2014). ANOVA for Factors With Ordered Levels. J Agric Biological Environmental Stat.

Examples

Run this code
# NOT RUN {
data(gomez.stripplot)
dat <- gomez.stripplot

# Gomez figure 3.7
desplot(gen~x*y, data=dat, out1=rep, num=nitro, cex=1,
        main="gomez.stripplot")

# Gertheiss figure 1
# dotplot(factor(nitro) ~ yield|gen, data=dat)

# Gomez table 3.12
tapply(dat$yield, dat$rep, sum)
tapply(dat$yield, dat$gen, sum)
tapply(dat$yield, dat$nitro, sum)

# Gomez table 3.15.  Anova table for strip-plot
dat <- transform(dat, nf=factor(nitro))
m1 <- aov(yield ~ gen * nf + Error(rep + rep:gen + rep:nf), data=dat)
summary(m1)

# }

Run the code above in your browser using DataLab