Learn R Programming

agridat (version 1.5)

kempton.uniformity: Uniformity trial of Spring Barley in 1978

Description

Uniformity trial of Spring Barley in 1978

Usage

data(kempton.uniformity)

Arguments

source

R. A. Kempton and C. W. Howes (1981). The use of neighbouring plot values in the analysis of variety trials. Applied Statistics, 30, 59--70.

Details

A uniformity trial of spring barley planted in 1978. Each plot is 5 feet wide, 14 feet long. Conducted by the Plant Breeding Institute in Cambridge, England.

References

McCullagh, P. and Clifford, D., (2006). Evidence for conformal invariance of crop yields, Proceedings of the Royal Society A: Mathematical, Physical and Engineering Science. 462, 2119--2143.

Examples

Run this code
dat <- kempton.uniformity

require(lattice)
desplot(yield~col*row, dat)
asp <- (28*14)/(7*5) # aspect ratio (rows * ft)/(cols * ft)
desplot(yield~col*row, dat, aspect=asp) # true view

Run the code above in your browser using DataLab