Learn R Programming

agridat (version 1.12)

rothamsted.brussels: Yield of brussels sprouts, RCB with 9 fertilizer treatments

Description

Yield of brussels sprouts, RCB with 9 fertilizer treatments

Arguments

Format

A data frame with 48 observations on the following 5 variables.

row

Row

col

Column

yield

Yield of saleable sprouts, pounds

trt

Treatment factor, 9 levels

block

Block factor, 4 levels

Details

The block numbers are arbitrary, and may not match the orignal source.

References

McCullagh, P. and Clifford, D., (2006). Evidence for conformal invariance of crop yields, Proceedings of the Royal Society A: Mathematical, Physical and Engineering Science, 462, 2119--2143.

Examples

Run this code
# NOT RUN {
data(rothamsted.brussels)
dat <- rothamsted.brussels

require(lattice)
bwplot(yield~trt, dat, main="rothamsted.brussels")
desplot(yield~col*row, data=dat, num=trt, out1=block, cex=1,
        main="rothamsted.brussels")

# }

Run the code above in your browser using DataLab