Learn R Programming

agridat (version 1.12)

beaven.barley: Yields of 8 barley varities in 1913 as used by Student.

Description

Yields of 8 barley varities in 1913.

Usage

data(beaven.barley)

Arguments

Format

A data frame with 160 observations on the following 4 variables.

row

row

col

column

gen

genotype factor

yield

yield (grams)

Details

Eight races of barley were grown on a regular pattern of plots.

These data were prepared from Richey (1926) because the copy was cleaner.

References

Frederick D. Richey (1926). The moving average as a basis for measuring correlated variation in agronomic experiments. Jour. Agr. Research, 32, 1161-1175.

Examples

Run this code
# NOT RUN {
data(beaven.barley)
dat <- beaven.barley

# Match the means shown in Richey table IV
tapply(dat$yield, dat$gen, mean)
##       a       b       c       d       e       f       g       h
## 298.080 300.710 318.685 295.260 306.410 276.475 304.605 271.820

# Compare to Student 1923, diagram I,II
desplot(yield ~ col*row, data=dat, aspect="iso",
        main="beaven.barley", text=gen)

# }

Run the code above in your browser using DataLab