Learn R Programming

agridat (version 1.5)

federer.tobacco: Height of Tobacco plants exposed to radiation

Description

Height of Tobacco plants exposed to radiation

Usage

data(federer.tobacco)

Arguments

source

Walter T Federer and C S Schlottfeldt, 1954. The use of covariance to control gradients in experiments. Biometrics, 10, 282--290.

Details

An experiment conducted in 1951 and described in Federer (1954). The treatment involved exposing tobacco seeds to seven different doses of radiation. The seedlings were transplanted to the field in an RCB experiment with 7 treatments in 8 blocks. The physical layout of the experiment was in 8 rows and 7 columns. Shortly after the plants were transplanted to the field it became apparent that an environmental gradient existed. The response variable was the total height (centimeters) of 20 plants.

References

R. D. Cook and S. Weisberg (1999). Applied Statistics Including Computing and Graphics. Walter T Federer and Russell D Wolfinger, 2003. PROC GLM and PROC MIXED Codes for Trend Analyses for Row-Column Designed Experiments, Handbook of Formulas and Software for Plant Geneticists and Breeders, Haworth Press. Paul N Hinz, 1987. Nearest-Neighbor Analysis in Practice, Iowa State Journal of Research, 62, 199--217.

Examples

Run this code
dat <- federer.tobacco

# RCB analysis.  Treatment factor not signficant.
dat <- transform(dat, dosef=factor(dose), rowf=factor(row),
                 blockf=factor(block))
m1 <- lm(height ~ blockf + dosef, data=dat)
anova(m1)

# RCB residuals show strong spatial trends
levelplot(resid(m1) ~ row * block, data=dat, col.regions=RedGrayBlue(21))

# Row-column analysis.  Treatment now significant
m2 <- lm(height ~ rowf + blockf + dosef, data=dat)
anova(m2)

Run the code above in your browser using DataLab