Learn R Programming

agridat (version 1.5)

gomez.stripplot: Rice strip-plot experiment

Description

A strip-plot experiment with three reps, variety as the horizontal strip and nitrogen fertilizer as the vertical strip.

Usage

data(gomez.stripplot)

Arguments

source

Gomez, K.A. and Gomez, A.A.. 1984, Statistical Procedures for Agricultural Research. Wiley-Interscience. Page 110. Used with permission of Kwanchai Gomez.

Examples

Run this code
dat <- gomez.stripplot

# Gomez figure 3.7
desplot(gen~x*y, data=dat, out1=rep, num=nitro, cex=1)

# Gomez table 3.12
tapply(dat$yield, dat$rep, sum)
tapply(dat$yield, dat$gen, sum)
tapply(dat$yield, dat$nitro, sum)

# Gomez table 3.15.  Anova table for strip-plot
dat <- transform(dat, nf=factor(nitro))
m1 <- aov(yield ~ gen * nf + Error(rep + rep:gen + rep:nf), data=dat)
summary(m1)

Run the code above in your browser using DataLab