dat <- gomez.stripsplitplot
# Layout
desplot(gen~x+y, dat, out1=rep, out2=gen, col=nitro, text=planting,
cex=1)
# Gomez table 4.19, ANOVA of strip-split-plot design
dat <- transform(dat, nf=factor(nitro))
m1 <- aov(yield ~ nf * gen * planting +
Error(rep + rep:nf + rep:gen + rep:nf:gen), data=dat)
summary(m1)
# There is a noticeable linear trend along the y coordinate which may be
# an artifact that blocking will remove, or may need to be modeled.
# Note the outside values in the high-nitro boxplot.
require("HH")
interaction2wt(yield ~ nitro + gen + planting + y, dat, x.relation="free")Run the code above in your browser using DataLab