Learn R Programming

agridat (version 1.12)

graybill.heteroskedastic: Wheat varieties with heteroskedastic yields

Description

Wheat varieties with heteroskedastic yields

Arguments

Format

A data frame with 52 observations on the following 3 variables.

env

Environment factor, 13 levels

gen

Genotype factor, 4 levels

yield

Yield

Details

Yield of 4 varieties of wheat at 13 locations in Oklahoma, USA.

The data was used to explore variability between varieties.

References

Hans-Pieter Piepho, 1994. Missing observations in the analysis of stability, Heredity, 72, 141--145.

Examples

Run this code
# NOT RUN {
data(graybill.heteroskedastic)
dat <- graybill.heteroskedastic

# Genotypes are obviously not homoscedastic
boxplot(yield ~ gen, dat, main="graybill.heteroskedastic")

# Shukla stability variance of each genotype, same as Grubbs' estimate
# Matches Piepho 1994 page 143.
# Do not do this!  Nowadays, use mixed models instead.
require("reshape2")
datm <- acast(dat, gen~env)
w <- datm
w <- sweep(w, 1, rowMeans(datm))
w <- sweep(w, 2, colMeans(datm))
w <- w + mean(datm)
w <- rowSums(w^2)
k=4; n=13
sig2 <- k*w/((k-2)*(n-1)) - sum(w)/((k-1)*(k-2)*(n-1))
## sig2
##     G1     G2     G3     G4
## 145.98 -14.14  75.15  18.25

# }

Run the code above in your browser using DataLab