Learn R Programming

agridat (version 1.12)

jansen.strawberry: Ordered disease ratings on strawberry crosses.

Description

Ordered disease ratings on strawberry crosses.

Usage

data(jansen.strawberry)

Arguments

Format

A data frame with 144 observations on the following 5 variables.

male

male parent

female

female parent

block

block factor, 4 levels

category

a factor with levels C1 C2 C3

count

number of plants in each category

Details

There were 3 male strawberry plants and 4 different female strawberry plants that were crossed to create 12 populations.

The experiment had four blocks with 12 plots each (one for each population). In each plot, 9 or 10 plants were assessed for damage from fungus and rated as belonging to category C1, C2, or C3 (increasing damage).

Red core disease is caused by a fungus, Phytophtora fragariae.

Examples

Run this code
# NOT RUN {
data(jansen.strawberry)
dat <- jansen.strawberry
dat <- transform(dat, category=ordered(category, levels=c('C1','C2','C3')))

ftable(xtabs(count~male + female + category, data=dat))
mosaicplot(xtabs(count~male + female + category, data=dat),
           color=c("lemonchiffon1","moccasin","lightsalmon1","indianred"),
           main="jansen.strawberry disease ratings",
           xlab="Male parent", ylab="Female parent")

# Todo: Need an example model

# }

Run the code above in your browser using DataLab