Learn R Programming

agridat (version 1.12)

john.alpha: Alpha lattice design of spring oats

Description

Alpha lattice design of spring oats

Arguments

Format

A data frame with 72 observations on the following 5 variables.

plot

Plot number

rep

Replicate factor

block

Incomplete block factor

gen

Genotype (variety) factor

yield

Dry matter yield (tonnes/ha)

Details

A spring oats trial grown in Craibstone, near Aberdeen. There were 24 varities in 3 replicates, each consisting of 6 incomplete blocks of 4 plots. Planted in a resolvable alpha design. The plots were laid out in a single line.

References

Piepho, H.P. and M\"ohring, J. (2007), Computing heritability and selection response from unbalanced plant breeding trials, Genetics, 177, 1881--1888.

Examples

Run this code
# NOT RUN {
data(john.alpha)
dat <- john.alpha

# RCB (no incomplete block)
m0 <- lm(yield ~ 0 + gen + rep, data=dat)

# Block fixed (intra-block analysis) (bottom of table 7.4 in John)
m1 <- lm(yield ~ 0 + gen + rep + rep:block, dat)
anova(m1)

# Block random (combined inter-intra block analysis)
if(require(lme4) & require(lucid)){
m2 <- lmer(yield ~ 0 + gen + rep + (1|rep:block), dat)

anova(m2)
## Analysis of Variance Table
##     Df Sum Sq Mean Sq  F value
## gen 24 380.43 15.8513 185.9942
## rep  2   1.57  0.7851   9.2123
vc(m2)
##        grp        var1 var2    vcov  sdcor
##  rep:block (Intercept) <NA> 0.06194 0.2489
##   Residual        <NA> <NA> 0.08523 0.2919


# Variety means.  John and Williams table 7.5.  Slight, constant
# difference for each method as compared to John and Williams.
means <- data.frame(rcb=coef(m0)[1:24],
                    ib=coef(m1)[1:24],
                    intra=fixef(m2)[1:24])
## head(means)
##             rcb       ib    intra
## genG01 5.201233 5.268742 5.146433
## genG02 4.552933 4.665389 4.517265
## genG03 3.381800 3.803790 3.537934
## genG04 4.439400 4.728175 4.528828
## genG05 5.103100 5.225708 5.075944
## genG06 4.749067 4.618234 4.575394
require(lattice)
splom(means, data=means, main="john.alpha - means for RCB, IB, Intra-block")

}

# }
# NOT RUN {
# Heritability calculation of Piepho & Mohring, Example 1
require(asreml)
m3 <- asreml(yield ~ 1 + rep, data=dat, random=~ gen + rep:block)
sg2 <- summary(m3)$varcomp[1,'component']
vblup <- predict(m3, classify="gen")$pred$avsed ^ 2
m3 <- asreml(yield ~ 1 + gen + rep, data=dat, random = ~ rep:block)
vblue <- predict(m3, classify="gen")$pred$avsed ^ 2
# H^2 = .803
sg2 / (sg2 + vblue/2)
# H^2c = .809
1-(vblup / 2 / sg2)
# }

Run the code above in your browser using DataLab