Learn R Programming

agridat (version 1.8.1)

lyon.potato.uniformity: Uniformity trial of potatoes

Description

Uniformity trial of potatoes

Arguments

source

Lyon, T.L. (1911). Some experiments to estimate errors in field plat tests. Proc. Amer. Soc. Agron, 3, 89-114. https://www.crops.org/publications/aj/abstracts/3/1/AJ0030010089

Details

In 1909, potatoes were harvested from uniform land. There were 34 rows, 34 inches apart. Each row was harvested in 6 sections, each being 72 feet, 7 inches long.

References

Harris, J.A. (1920). Practical universality of field heterogeneity as a factor influencing plot yields. Journal of Agricultural Research, 19, 279-314. http://books.google.com/books?id=jyEXAAAAYAAJ&pg=PA279

Examples

Run this code
dat <- lyon.potato.uniformity
desplot(yield ~ row*section, dat, tick=TRUE,
        main="lyon.potato.uniformity")

Run the code above in your browser using DataLab