Learn R Programming

agridat (version 1.8.1)

mead.germination: Seed germination with different temperatures/concentrations

Description

Seed germination with different temperatures/concentrations

Arguments

source

Roger Mead, Robert N Curnow, Anne M Hasted. 2002. Statistical Methods in Agriculture and Experimental Biology, 3rd ed. Chapman and Hall. Page 350-351. Used with permission of Roger Mead, Robert Curnow, and Anne Hasted.

Details

The rep factor is NOT a blocking factor.

References

Schabenberger, O. and Pierce, F.J., 2002. Contemporary statistical models for the plant and soil sciences, CRC.

Examples

Run this code
dat <- mead.germination
dat <- transform(dat, concf=factor(conc))
xyplot(germ~log(conc+.01)|temp, dat, layout=c(4,1))

m1 <- glm(cbind(germ, seeds-germ) ~ 1, dat, family=binomial)
m2 <- glm(cbind(germ, seeds-germ) ~ temp, dat, family=binomial)
m3 <- glm(cbind(germ, seeds-germ) ~ concf, dat, family=binomial)
m4 <- glm(cbind(germ, seeds-germ) ~ temp + concf, dat, family=binomial)
m5 <- glm(cbind(germ, seeds-germ) ~ temp * concf, dat, family=binomial)
anova(m1,m2,m3,m4,m5)

# Show logit and fitted values.  T2 has highest germination
subset(cbind(dat, predict(m5), fitted(m5)), rep=="R1")

Run the code above in your browser using DataLab