desplot which fills cells with
a background color and adds outlines around blocks of cells.panel.outlinelevelplot(x, y, z, subscripts, at, ...,
alpha.regions = 1, out1f, out1g, out2f, out2g)desplot which fills cells with
a background color and adds outlines around blocks of cells.
It does not add the text labels, numbers, or colors.
The rule for determining where to draw outlines is to compare the
levels of the factor used for outlining. If bordering cells have
different levels of the factor, then a border is drawn. 'NA' values
are ignored (otherwise, too many lines would be drawn).
The code works, but is probably overkill and has not been streamlined.