Learn R Programming

agridat (version 1.5)

vargas.wheat2: Wheat yields for a multi-environment trial and environmental covariates

Description

The yield of 8 wheat genotypes was measured in 21 low-humidity environments. Each environment had 13 covariates recorded.

Usage

data(vargas.wheat2)

Arguments

format

A list of two matrices, yield and covs. See below.

source

Mateo Vargas and Jose Crossa and Ken Sayre and Matthew Renolds and Martha E Ramirez and Mike Talbot, 1998. Interpreting Genotype x Environment Interaction in Wheat by Partial Least Squares Regression, Crop Science, 38, 679--689. Data kindly provided by Jose Crossa.

Details

The yield matrix contains grain yields (kg/ha) for 8 wheat genotypes at 21 low-humidity environments grown during 1990-1994. The matrix is double-centered so that the rows and columns have mean zero. The locations of the experiments were: ll{ OBD Ciudad Obregon, Mexico, planted in December SUD Wad Medani, Sudan TLD Tlaltizapan, Mexico, planted in December TLF Tlaltizapan, Mexico, planted in February IND Dharwar, India SYR Aleppo, Syria NIG Kadawa, Nigeria } The covs matrix has values of 13 covariates at the same 21 environments. The covariates are: ll{ CYC length of growth cycle in days mTC mean daily minimum temperature in degrees Celsius MTC mean daily maximum temperature SHC sun hours per day mTV mean daily minimum temp during vegetative stage MTV mean daily maximum temp during vegetative stage SHV sun hours per day during vegetative stage mTS mean daily minimum temp during spike growth stage MTS mean daily maximum temp during spike growth stage SHS sun hours per day during spike growth stage mTG mean daily minimum temp during grainfill stage MTG mean daily maximum temp during grainfill stage SHG sun hours per day during grainfill stage }

Examples

Run this code
dat <- vargas.wheat2
yield <- dat$yield
covs <- dat$covs

# The pls package centers, but does not (by default) use scaled covariates
# Vargas says you should
# yield <- scale(yield)
covs <- scale(covs)

require(pls)
m2 <- plsr(yield ~ covs)

# Plot predicted vs observed for each genotype using all components
plot(m2)

# Loadings
plot(m2, "loadings", xaxt='n')
axis(1, at=1:ncol(covs), labels=colnames(covs), las=2)

# Biplots
biplot(m2, cex=.5, which="y", var.axes=TRUE) # Vargas figure 2a
biplot(m2, cex=.5, which="x", var.axes=TRUE) # Vectors form figure 2 b
biplot(m2, cex=.5, which="scores", var.axes=TRUE)
biplot(m2, cex=.5, which="loadings", var.axes=TRUE)

Run the code above in your browser using DataLab