Learn R Programming

agridat (version 1.12)

verbyla.lupin: Lupin yields for different varieties and locations, at many densities

Description

Yield of 9 varieties of lupin at different planting densities across 2 years and multiple locations.

Arguments

Format

gen

Genotype factor, 9 varieties

site

Site factor, 11 levels

rate

seeding rate in plants/m^2

row

row

col

column

serp

factor of 4 levels for serpentine seeding effect

linrow

centered row position as a numeric variate (row-8.5)/10

lincol

centered column position as a numeric variate (col-3.5)

linrate

linear effect of seedrate, scaled (seedrate-41.92958)/10

yield

yield in tons/hectare

year

year

loc

Location factor

Details

Nine varieties of lupin were tested for yield response to plant density at 11 sites. The target density in 1991 was 10, 20, ..., 60 plants per m^2, and in 1992 was 20, 30, ..., 70 plants per m^2. The variety Myallie was grown only in 1992. Each site had 2 reps in 1991 and 3 reps in 1992. Each rep was laid out as an RCB design; one randomization was used for all sites in 1991 and one (different) randomization was used for all sites in 1992. (This was confirmed with the principal investigator.) In 1991 at the Mt. Barker location, the data for columns 5 and 6 was discarded due to problems with weeds.

The year of release for the varieties is

Unicrop 1973
Illyarrie 1979
Yandee 1980
Danja 1986
Gungurru 1988
Yorrel 1989
Warrach 1989
Merrit 1991
Myallie 1995

Examples

Run this code
# NOT RUN {
data(verbyla.lupin)
dat <- verbyla.lupin

# The same RCB randomization was used at all sites in each year
desplot(gen~col+row|site, data=dat, main="verbyla.lupin")

# Figure 3 of Verbyla
require(lattice)
foo <- xyplot(yield ~ rate|loc*gen, data=dat, subset=year==92,
              type=c('p','smooth'), cex=.5,
              main="verbyla.lupin: 1992", xlab="Seed rate (plants/m^2)",
              ylab="Yield (tons/ha)",
              strip=strip.custom(par.strip.text=list(cex=.7)))

if (require(latticeExtra)) { # for useOuterStrips
  useOuterStrips(foo,
                 strip=strip.custom(par.strip.text=list(cex=.7)),
                 strip.left=strip.custom(par.strip.text=list(cex=.7)))
} else {
  print(foo)
}

# }

Run the code above in your browser using DataLab