Learn R Programming

agridat (version 1.5)

yan.winterwheat: Multi-environment trial of Winter Wheat in Ontario

Description

Yield of 18 varieties of winter wheat grown at 9 environments in Ontario in 1993.

Usage

data(yan.winterwheat)

Arguments

source

Weikai Yan and M.S. Kang. GGE biplot analysis: A graphical tool for breeders, geneticists, and agronomists, 2002. CRC. Page 59. Used with permission of Weikai Yan.

Details

The yield is the mean of several reps, measured in metric tons per hectare. This data has often been used to illustrate GGE biplots.

References

Weikai Yan and Manjit S. Kang and Baoluo Ma and Sheila Woods, 2007, GGE Biplot vs. AMMI Analysis of Genotype-by-Environment Data, Crop Science, 2007, 47, 641--653.

Examples

Run this code
require("reshape2")
mat <- melt(yan.winterwheat, id.var=c('gen','env'))
mat <- acast(mat, gen~env)

mat.sc <- scale(mat)

# Environment-standardized GGE biplot
biplot(princomp(mat.sc))

Run the code above in your browser using DataLab